@@ -13,12 +13,14 @@ Unless required by applicable law or agreed to in writing, software distributed
 
 import functools
 import logging
-
-from connexion.decorators.produces import BaseSerializer, Produces, Jsonifier
-from connexion.decorators.security import security_passthrough, verify_oauth
-from connexion.decorators.validation import RequestBodyValidator, ParameterValidator
-from connexion.exceptions import InvalidSpecification
-from connexion.utils import flaskify_endpoint, get_function_from_name, produces_json
+import os
+from .decorators.parameter import parameter_to_arg
+from .decorators.produces import BaseSerializer, Produces, Jsonifier
+from .decorators.security import security_passthrough, verify_oauth
+from .decorators.validation import RequestBodyValidator, ParameterValidator
+from .decorators.metrics import UWSGIMetricsCollector
+from .exceptions import InvalidSpecification
+from .utils import flaskify_endpoint, get_function_from_name, produces_json
 
 logger = logging.getLogger('connexion.operation')
 
@@ -139,16 +141,32 @@ class Operation:
 
         :rtype: types.FunctionType
         """
+
+        parameters = []
+        for param in self.parameters:  # resolve references
+            param = param.copy()
+            schema = param.get('schema')
+            if schema:
+                schema = self.resolve_reference(schema)
+            param['schema'] = schema
+            parameters.append(param)
+        function = parameter_to_arg(parameters, self.__undecorated_function)
+
         produces_decorator = self.__content_type_decorator
         logger.debug('... Adding produces decorator (%r)', produces_decorator, extra=vars(self))
-        function = produces_decorator(self.__undecorated_function)
+        function = produces_decorator(function)
 
+        for validation_decorator in self.__validation_decorators:
+            function = validation_decorator(function)
+
+        # NOTE: the security decorator should be applied last to check auth before anything else :-)
         security_decorator = self.__security_decorator
         logger.debug('... Adding security decorator (%r)', security_decorator, extra=vars(self))
         function = security_decorator(function)
 
-        for validation_decorator in self.__validation_decorators:
-            function = validation_decorator(function)
+        if UWSGIMetricsCollector.is_available():
+            decorator = UWSGIMetricsCollector(self.path, self.method)
+            function = decorator(function)
 
         return function
 
@@ -215,7 +233,7 @@ class Operation:
         logger.debug('... Security: %s', self.security, extra=vars(self))
         if self.security:
             if len(self.security) > 1:
-                logger.warning("... More than security requirement defined. **IGNORING SECURITY REQUIREMENTS**",
+                logger.warning("... More than one security requirement defined. **IGNORING SECURITY REQUIREMENTS**",
                                extra=vars(self))
                 return security_passthrough
 
@@ -226,13 +244,17 @@ class Operation:
             scheme_name, scopes = next(iter(security.items()))  # type: str, list
             security_definition = self.security_definitions[scheme_name]
             if security_definition['type'] == 'oauth2':
-                token_info_url = security_definition.get('x-tokenInfoUrl')
+                token_info_url = security_definition.get('x-tokenInfoUrl', os.getenv('HTTP_TOKENINFO_URL'))
                 if token_info_url:
                     scopes = set(scopes)  # convert scopes to set because this is needed for verify_oauth
                     return functools.partial(verify_oauth, token_info_url, scopes)
                 else:
                     logger.warning("... OAuth2 token info URL missing. **IGNORING SECURITY REQUIREMENTS**",
                                    extra=vars(self))
+            elif security_definition['type'] in ('apiKey', 'basic'):
+                logger.debug(
+                    "... Security type '%s' not natively supported by Connexion; you should handle it yourself",
+                    security_definition['type'], extra=vars(self))
             else:
                 logger.warning("... Security type '%s' unknown. **IGNORING SECURITY REQUIREMENTS**",
                                security_definition['type'], extra=vars(self))
